<?php
/**
 * The template for displaying comments.
 *
 * This is the template that displays the area of the page that contains both the current comments
 * and the comment form.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package Moon
 */

/*
 * If the current post is protected by a password and
 * the visitor has not yet entered the password we will
 * return early without loading the comments.
 */
if ( post_password_required() ) {
	return;
}
?>

<div id="comments" class="comments-area">

	<?php // You can start editing here -- including this comment! ?>

	<?php if ( have_comments() ) : ?>
		<h2 class="comments-title">
			<?php
				printf( // WPCS: XSS OK.
					esc_html( _nx( 'One thought on &ldquo;%2$s&rdquo;', '%1$s thoughts on &ldquo;%2$s&rdquo;', get_comments_number(), 'comments title', 'moon' ) ),
					number_format_i18n( get_comments_number() ),
					'<span>' . get_the_title() . '</span>'
				);
			?>
		</h2>

		<?php if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) : // Are there comments to navigate through? ?>
		<nav id="comment-nav-above" class="navigation comment-navigation" role="navigation">
			<h2 class="screen-reader-text"><?php esc_html_e( 'Comment navigation', 'moon' ); ?></h2>
			<div class="nav-links">

				<div class="nav-previous"><?php previous_comments_link( esc_html__( 'Older Comments', 'moon' ) ); ?></div>
				<div class="nav-next"><?php next_comments_link( esc_html__( 'Newer Comments', 'moon' ) ); ?></div>

			</div><!-- .nav-links -->
		</nav><!-- #comment-nav-above -->
		<?php endif; // Check for comment navigation. ?>

		<ol class="comment-list">
			<?php
				wp_list_comments( array(
					'style'      => 'ol',
					'short_ping' => true,
					'callback'   => 'nq_moon_comments_list',
				) );
			?>
		</ol><!-- .comment-list -->

		<?php if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) : // Are there comments to navigate through? ?>
		<nav id="comment-nav-below" class="navigation comment-navigation" role="navigation">
			<h2 class="screen-reader-text"><?php esc_html_e( 'Comment navigation', 'moon' ); ?></h2>
			<div class="nav-links">

				<div class="nav-previous"><?php previous_comments_link( esc_html__( 'Older Comments', 'moon' ) ); ?></div>
				<div class="nav-next"><?php next_comments_link( esc_html__( 'Newer Comments', 'moon' ) ); ?></div>

			</div><!-- .nav-links -->
		</nav><!-- #comment-nav-below -->
		<?php endif; // Check for comment navigation. ?>

	<?php endif; // Check for have_comments(). ?>

	<?php
		// If comments are closed and there are comments, let's leave a little note, shall we?
		if ( ! comments_open() && get_comments_number() && post_type_supports( get_post_type(), 'comments' ) ) :
	?>
		<p class="no-comments"><?php esc_html_e( 'Comments are closed.', 'moon' ); ?></p>
	<?php endif; ?>

	<?php
		$args = array(
			'comment_notes_before' => '',
			'fields' => '
				<p class="comment-form-author">
					<input placeholder="' . esc_attr__( 'Your name', 'moon' ) . '" type="text" required="required" size="30" value="" name="author" id="author">
				</p>
				<p class="comment-form-email">
					<input placeholder="' . esc_attr__( 'Your email', 'moon' ) . '" type="email" required="required" size="30" value="" name="email" id="email">
				</p>
				<p class="comment-form-url">
    				<input placeholder="' . esc_attr__( 'Your website', 'moon' ) . '" type="text" value="" size="30"  name="url" id="url" /></p>
			',

			// change the title of the reply section
			'title_reply'=> __( 'Leave your comment', 'moon' ),

			// remove "Text or HTML to be displayed after the set of comment fields"
			'comment_notes_after' => '',

			// redefine your own textarea (the comment body)
			'comment_field' => '<p class="comment-form-comment"><textarea rows="6" placeholder="' . esc_attr__( 'Your comment', 'moon' ) . '" name="comment" aria-required="true"></textarea></p>',

			// change the title of send button 
			'label_submit'=> __( 'Post comment', 'moon' ),
		);

		comment_form( $args );
	?>

</div><!-- #comments -->
