<?php
/**
 * Moon helpers functions.
 *
 * @since   1.0.0
 * @package Moon
 */

/**
 * Display Site Branding.
 * 
 * @since  1.0.0
 * @return void
 */
if ( ! function_exists( 'nq_moon_site_branding' ) ) {
	function nq_moon_site_branding( $output ) {
		$logo = get_theme_mod( 'logo' );

		$output .= '<div class="site-branding">';
			$output .= '<a href="' . esc_url( home_url( '/' ) ) . '" rel="home">';
				if ( ! empty( $logo ) ) {
					$data = getimagesize( $logo );
					$output .='<img class="logo" src="' . esc_url( $logo ) . '" alt="' . get_bloginfo( 'name' ) . '" width="' . esc_attr( $data[0] ) . '" height="' . esc_attr( $data[1] ) . '" />';
				} else {
					$output .='<img class="logo" src="' . get_template_directory_uri() . '/assets/images/logo.png' . '" alt="' . get_bloginfo( 'name' ) . '" width="250" height="60" />';
				}
			$output .= '</a>';

			if ( '' != get_bloginfo( 'description' ) ) {
				$output .= '<p class="site-description">' . get_bloginfo( 'description' ) . '</p>';
			}
		$output .= '</div>';

		echo apply_filters( 'nq_moon_site_branding', $output );
	}
}

/**
 * Display Main Menu.
 * 
 * @since  1.0.0
 * @return void
 */
if ( ! function_exists( 'nq_moon_site_navigation' ) ) {
	function nq_moon_site_navigation( $output ) {
		$output .= '<div class="site-navigation" role="navigation">';
			$output .= '<div class="container">';
				$output .= '<a class="mobile-trigger" href="javascript:void(0);"><span></span></a>';
				$output .= wp_nav_menu(
					array(
						'theme_location' => 'primary',
						'menu_id'        => 'primary-menu',
						'menu_class'     => 'clear',
						'container'      => false,
						'echo'           => false,
						'fallback_cb'    => '',
					)
				);
				$output .= '<div class="site-search">';
					$output .= '<i class="moon-icon-search"></i>';
					$output .= '<form role="search" method="get" class="searchform" action="' . esc_url( home_url( '/' ) ) . '">';
						$output .= '<input type="text" value="" name="s" placeholder="' . esc_html__( 'Type your Keyword &amp; press &quot;Enter&quot;', 'moon' ) . '" />';
						$output .= '<a class="close"><img src="' . get_template_directory_uri() . '/assets/images/icon-close.png" width="40" height="40" alt="Close" /></a>';
					$output .= '</form>';
				$output .= '</div>';
			$output .= '</div>';
		$output .= '</div>';

		echo apply_filters( 'nq_moon_site_navigation', $output );
	}
}

/**
 * Prints title of blog post.
 * 
 * @since  1.0.0
 * @return void
 */
if ( ! function_exists( 'nq_moon_post_title' ) ) {
	function nq_moon_post_title() {
		the_title( sprintf( '<h2 class="entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h2>' );
	}
}

/**
 * Prints HTML with meta information for the current post-date/time and author.
 * 
 * @since  1.0.0
 * @return void
 */
if ( ! function_exists( 'nq_moon_posted_on' ) ) {
	function nq_moon_posted_on() {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';

		$time_string = sprintf( $time_string,
			esc_attr( get_the_date( 'c' ) ),
			esc_html( get_the_date() )
		);

		$posted_on = sprintf(
			esc_html_x( '%s', 'post date', 'moon' ),
			'<i class="moon-icon-calendar"></i><a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
		);

		echo '<span class="posted-on">' . $posted_on . '</span>';
	}
}

/**
 * Prints HTML author post.
 * 
 * @since  1.0.0
 * @return void
 */
if ( ! function_exists( 'nq_moon_post_author' ) ) {
	function nq_moon_post_author() {
		$byline = sprintf(
			esc_html_x( '%s', 'post author', 'moon' ),
			'<a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a>'
		);

		echo '<span class="byline author vcard"><i class="moon-icon-user"></i>' . $byline . '</span>';
	}
}

/**
 * Prints HTML with meta information for the comments.
 * 
 * @since  1.0.0
 * @return void
 */
if ( ! function_exists( 'nq_moon_post_comments' ) ) :
	function nq_moon_post_comments() {
		if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
			echo '<span class="comments-link"><i class="moon-icon-bubble"></i>';
			comments_popup_link( esc_html__( 'Leave a comment', 'moon' ), esc_html__( '1 Comment', 'moon' ), esc_html__( '% Comments', 'moon' ) );
			echo '</span>';
		}
	}
endif;

/**
 * Prints HTML with meta information for the categories.
 * 
 * @since  1.0.0
 * @return void
 */
if ( ! function_exists( 'nq_moon_post_cats' ) ) :
	function nq_moon_post_cats() {
		// Hide category and tag text for pages.
		if ( 'post' === get_post_type() ) {
			/* translators: used between list items, there is a space after the comma */
			$categories_list = get_the_category_list( esc_html__( ', ', 'moon' ) );
			if ( $categories_list && nq_moon_categorized_blog() ) {
				printf( '<span class="cat-links"><i class="moon-icon-pen"></i>' . esc_html__( '%1$s', 'moon' ) . '</span>', $categories_list ); // WPCS: XSS OK.
			}
		}
	}
endif;

/**
 * Prints HTML with meta information for the tags.
 * 
 * @since  1.0.0
 * @return void
 */
if ( ! function_exists( 'nq_moon_post_tags' ) ) :
	function nq_moon_post_tags() {
		// Hide category and tag text for pages.
		if ( 'post' === get_post_type() ) {
			/* translators: used between list items, there is a space after the comma */
			$tags_list = get_the_tag_list( '', esc_html__( ', ', 'moon' ) );
			if ( $tags_list ) {
				printf( '<span class="tags-links"><i class="moon-icon-tag"></i>' . esc_html__( '%1$s', 'moon' ) . '</span>', $tags_list ); // WPCS: XSS OK.
			}
		}
	}
endif;

/**
 * Prints HTML with meta information for the tags.
 * 
 * @since  1.0.0
 * @return void
 */
if ( ! function_exists( 'nq_moon_post_read_more' ) ) :
	function nq_moon_post_read_more() {
		global $post;
		if ( strpos( $post->post_content , "<!--more-->" ) != false ) :
			echo '<a class="more-link" href="' . esc_url( get_permalink() ) . '">' . esc_html__( 'Read more', 'moon' ) . '</a>';
		endif;
	}
endif;

/**
 * Display the post thumbnail follow post format.
 * 
 * @since  1.0.0
 * @return void
 */
if ( ! function_exists( 'nq_moon_post_thumbnail' ) ) {
	function nq_moon_post_thumbnail() {
		global $post;
		// Get post format
		$post_format = get_post_format();

		switch ( $post_format ):
			case 'gallery' :
				// Get image id
				$images = get_post_meta( get_the_ID(), 'nq_moon_gallery', false );
				$photos = array();

				foreach ( $images as $id ) {
					$link     = wp_get_attachment_image_src( $id, 'full' );
					$photos[] = $link[0];
				}

				// Main slider
				if ( ! empty( $photos ) ) {
					echo '<div class="moon-gallery">';
						foreach ( $photos as $photo ) {
							$data = getimagesize( $photo );
							echo '<img src="' . esc_url( $photo ) . '" width="' . esc_attr( $data[0] ) . '" height="' . esc_attr( $data[1] ) . '" alt="' . get_the_title() . '" />';
						}
					echo '</div>';
				} elseif ( has_post_thumbnail() ) {
					echo '<a href="' . esc_url( get_permalink() ) . '">';
						the_post_thumbnail();
					echo '</a>';
				}
			break;

			case 'audio' :
				$audio      = get_post_meta( $post->ID, 'nq_moon_audio_source', true );
				$soundcloud = get_post_meta( $post->ID, 'nq_moon_audio_link', true );
				$localfile  = get_post_meta( $post->ID, 'nq_moon_audio_self_hosted', true );

				if ( 'link' == $audio ) {
					global $wp_embed;
					$media_result = $wp_embed->run_shortcode( '[embed]' . esc_url( $soundcloud ) . '[/embed]' );
					echo $media_result;
				} elseif ( 'local' == $audio ) {
					echo do_shortcode('[audio src="' . esc_url( $localfile ) . '"/]');
				} elseif ( has_post_thumbnail() ) {
					echo '<a href="' . esc_url( get_permalink() ) . '">';
						the_post_thumbnail();
					echo '</a>';
				}
			break;

			case 'video' :
				$video       = get_post_meta( $post->ID, 'nq_moon_video_source', true );
				$video_url   = get_post_meta( $post->ID, 'nq_moon_video_link', true );
				$video_embed = get_post_meta( $post->ID, 'nq_moon_video_embed', true );
				$video_local = get_post_meta( $post->ID, 'nq_moon_video_self_hosted', true );

				if ( 'link' == $video ) {
					global $wp_embed;
					$media_result = $wp_embed->run_shortcode( '[embed]' . esc_url( $video_url ) . '[/embed]' );
					echo $media_result;
				} elseif ( 'embed' == $video ) {
					echo $video_embed;
				} elseif ( 'local' == $video ) {
					echo do_shortcode('[video src="' . esc_url( $video_local ) . '"/]');
				} elseif ( has_post_thumbnail() ) {
					echo '<a href="' . esc_url( get_permalink() ) . '">';
						the_post_thumbnail();
					echo '</a>';
				}
			break;

			case 'quote' :
			default :
				if ( has_post_thumbnail() ) {
					echo '<a href="' . esc_url( get_permalink() ) . '">';
						the_post_thumbnail();
					echo '</a>';
				}
			break;
		endswitch;
	}
}

/**
 * Display navigation to next/previous set of posts when applicable.
 *
 * @since 1.0.0
 * @return void
 */
if ( ! function_exists( 'nq_moon_pagination' ) ) {
	function nq_moon_pagination( $nav_query = false ) {

		global $wp_query, $wp_rewrite;

		// Don't print empty markup if there's only one page.
		if ( $GLOBALS['wp_query']->max_num_pages < 2 ) {
			return;
		}

		// Prepare variables
		$query        = $nav_query ? $nav_query : $wp_query;
		$max          = $query->max_num_pages;
		$current_page = max( 1, get_query_var( 'paged' ) );
		$big          = 999999;
		?>
		<nav class="pagination">
			<?php
				echo '' . paginate_links(
					array(
						'base'      => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
						'format'    => '?paged=%#%',
						'current'   => $current_page,
						'total'     => $max,
						'type'      => 'list',
						'prev_text' => '<span class="dashicons dashicons-arrow-left-alt"></span>',
						'next_text' => '<span class="dashicons dashicons-arrow-right-alt"></span>'
					)
				) . ' ';
			?>
		</nav><!-- .page-nav -->
		<?php
	}
}

/**
 * Render social share.
 * 
 * @since  1.0.0
 * @return void
 */
if ( ! function_exists( 'nq_moon_social_share' ) ) :
	function nq_moon_social_share( $output ) {
		global $post;

		// Get post thumbnail
		$src = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), false, '' );
	?>
		<div class="social-share">
			<a class="action" href="javascript:void(0);"><i class="dashicons dashicons-share"></i></a>
			<div class="social">
				<a title="<?php echo esc_html__( 'Share this post on Facebook', 'moon' ); ?>" class="facebook" href="http://www.facebook.com/sharer.php?u=<?php esc_url( the_permalink() ); ?>" onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;">
					<i class="dashicons dashicons-facebook-alt"></i>
				</a>
				<a title="<?php echo esc_html__( 'Share this post on Twitter', 'moon' ); ?>" class="twitter" href="https://twitter.com/share?url=<?php esc_url( the_permalink() ); ?>" onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;">
					<i class="dashicons dashicons-twitter"></i>
				</a>
				<a title="<?php echo esc_html__( 'Share this post on Google Plus', 'moon' ); ?>" class="google-plus" href="https://plus.google.com/share?url=<?php esc_url( the_permalink() ); ?>" onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;">
					<i class="dashicons dashicons-googleplus"></i>
				</a>
			</div><!-- .social -->
		</div>
	<?php
	}
endif;

/**
 * Render post author.
 *
 * @since  1.0.0
 * @return string
 */
if ( ! function_exists( 'nq_moon_get_author' ) ) :
	function nq_moon_get_author() {
		$author = sprintf(
			__( '<div class="post-author">%1$s%2$s</div>', 'moon' ),
			get_avatar( get_the_author_meta( 'user_email' ), '60', '' ),
			'<div class="author-info"><a class="name" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a><p>' . get_the_author_meta( 'description' ) . '</p></div>'

		);
		echo $author;
	}
endif;

/**
 * Returns true if a blog has more than 1 category.
 *
 * @since  1.0.0
 * @return bool
 */
function nq_moon_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'moon_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,

			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'moon_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so nq_moon_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so nq_moon_categorized_blog should return false.
		return false;
	}
}

/**
 * custom function to use to open and display each comment
 *
 * @since   1.0.0
 * @return  string
 */
if ( ! function_exists( 'nq_moon_comments_list' ) ) :
	function nq_moon_comments_list( $comment, $args, $depth ) {
	// Globalize comment object
		$GLOBALS['comment'] = $comment;

		switch ( $comment->comment_type ) :

			case 'pingback'  :
			case 'trackback' :
				?>
				<li <?php comment_class(); ?> id="comment-<?php comment_ID(); ?>">
					<p>
						<?php
						_e( 'Pingback:', 'moon' );
						comment_author_link();
						edit_comment_link( __( 'Edit', 'moon' ), '<span class="edit-link">', '</span>' );
						?>
					</p>
				<?php
			break;

			default :
				global $post;
				?>
				<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
					<article id="comment-<?php comment_ID(); ?>" class="comment-body">
						<div class="comment-avatar">
							<?php echo get_avatar( $comment, 40 ); ?>
						</div>
						<div class="comment-content">
							<?php if ( '0' == $comment->comment_approved ) : ?>
								<p class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'moon' ); ?></p>
							<?php endif; ?>

							<div class="comment-meta">
								<?php
								printf(
									'<span class="comment-author">%1$s</span>',
									get_comment_author_link(),
									( $comment->user_id == $post->post_author ) ? '<span class="author-post">' . __( 'Post author', 'moon' ) . '</span>' : ''
								);

								printf(
									'<a href="%1$s"><time><span> - </span> %3$s</time></a>',
									esc_url( get_comment_link( $comment->comment_ID ) ),
									get_comment_time( 'c' ),
									sprintf( __( '%1$s at %2$s', 'moon' ), get_comment_date(), get_comment_time() )
								);

								?>
							</div>
							<?php comment_text(); ?>

							<div class="action-link">
								<?php
									edit_comment_link( __( '<span>Edit</span>', 'moon' ) );
									comment_reply_link(
										array_merge(
											$args,
											array(
												'reply_text' => __( '<span>Reply</span>', 'moon' ),
												'depth'      => $depth,
												'max_depth'  => $args['max_depth'],
											)
										)
									);
								?>
							</div><!-- .action-link -->
						</div><!-- .comment-content -->
					</article><!-- #comment- -->
				<?php
			break;

		endswitch;
	}
endif;

/**
 * Display Site Info.
 * 
 * @since  1.0.0
 * @return void
 */
if ( ! function_exists( 'nq_moon_site_info' ) ) {
	function nq_moon_site_info( $output ) {
		$copyright = get_theme_mod( 'footer_content' );
		$output .= '<div class="site-info">';
			if ( ! empty( $copyright ) ) {
				$output .= $copyright;
			} else {
				$output .= sprintf( esc_html__( '&copy; %1$s Moon - All Rights Reserved.', 'moon' ), get_the_time( 'Y' ) );
			}
		$output .= '</div>';

		echo apply_filters( 'nq_moon_site_info', $output );
	}
}

/**
 * Footer widget areas.
 *
 * @since 1.0.0
 */
if ( ! function_exists( 'nq_moon_footer_widget_area' ) ) {
	function nq_moon_footer_widget_area() {
		// Count the number of footer sidebars	
		$count = 0;

		if ( ! ( is_active_sidebar( 'footer-1' ) || is_active_sidebar( 'footer-2' ) || is_active_sidebar( 'footer-3' ) || is_active_sidebar( 'footer-4' ) ) ) return;

		if ( is_active_sidebar( 'footer-1' ) )
			$count++;

		if ( is_active_sidebar( 'footer-2' ) )
			$count++;

		if ( is_active_sidebar( 'footer-3' ) )
			$count++;

		if ( is_active_sidebar( 'footer-4' ) )
			$count++;

		$i = 1; $i <= 4; $i++;

		// Render footer widget sidebar
		echo '<div class="footer-widget">';
			switch ( $count ) {
				case '1' :
					for ( $i = 1; $i <= 1; $i++ ) {
						echo '<div class="col-1">';
							dynamic_sidebar( 'footer-' . $i );
						echo '</div>';
					}
					break;
				case '2' :
					for ( $i = 1; $i <= 2; $i++ ) {
						echo '<div class="col-2">';
							dynamic_sidebar( 'footer-' . $i );
						echo '</div>';
					}
					break;
				case '3' :
					for ( $i = 1; $i <= 3; $i++ ) {
						echo '<div class="col-3">';
							dynamic_sidebar( 'footer-' . $i );
						echo '</div>';
					}
					break;
				case '4' :
					for ( $i = 1; $i <= 4; $i++ ) {
						echo '<div class="col-4">';
							dynamic_sidebar( 'footer-' . $i );
						echo '</div>';
					}
					break;
			}
		echo '</div>';
	}
}

/**
 * Get custom data to js.
 *
 * @since 1.2.3
 */
if ( ! function_exists( 'nq_moon_custom_data_js' ) ) {
	function nq_moon_custom_data_js() {
		$data = array();

		// Header Sticky
		$data['header_sticky'] = get_theme_mod( 'header_fixed', 0 );

		return $data;
	}
}