<?php
/**
 * Dribbble widget.
 *
 * @package Moon
 * @since   1.0.0
 */

class NQ_Moon_Widget_Dribbble extends WP_Widget {

	function __construct() {
		$widget_ops  = array(
			'description' => __( 'Show off your favorite Dribbble photos', 'moon' )
		);
		$control_ops = array(
			'width'  => 'auto',
			'height' => 'auto'
		);
		parent::__construct( 'moon_dribbble', __( 'Moon - Dribbble', 'moon' ), $widget_ops, $control_ops );
	}

	function widget( $args, $instance ) {
		extract( $args );
		$title   = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );
		$id      = empty($instance['id']) ? '' : $instance['id'];
		$limit   = empty( $instance['limit'] ) ? 4 : ( int ) $instance['limit'];
		$columns = empty( $instance['columns'] ) ? 2 : ( int ) $instance['columns'];

		echo $before_widget;
		
		if ( ! empty( $title ) ) {
			echo $before_title . $title . $after_title;
		}

		$output = '';

		$user     = 'https://api.dribbble.com/v1/users/' . esc_attr( $id ) . '?access_token=1792c5add5b9abe0baf1bfc492cfd5236cb18ea7c8d8cc31fb9fcdde7bbe0276';
		$getusers = wp_remote_get( $user );

		if ( ! is_wp_error( $getusers ) ) {
			$json_decode = json_decode( $getusers['body'], true );

			// Get Dribbble shot
			if ( isset( $json_decode ) ) {
				$shot    = $json_decode['shots_url'] . '?per_page=' . esc_attr( $limit ) . '&access_token=1792c5add5b9abe0baf1bfc492cfd5236cb18ea7c8d8cc31fb9fcdde7bbe0276';
				$getshot =  wp_remote_get( $shot );

				if ( ! is_wp_error( $getshot ) && isset( $getshot['body'] ) && $getshot['body'] )
					$shots = json_decode( $getshot['body'], true );
			}

			if ( isset( $shots ) && $shots ) {
				$output .= '<div class="dribbble clear cols-' . esc_attr( $columns ) . '">';
					foreach ( $shots as $key => $value ) {
						$output .= '<div class="item">';
							$output .= '<a href="' . esc_url( $value['html_url'] ) . '">';
								$output .= '<img src="' . esc_url( $value['images']['teaser'] ) . '" alt="' . esc_attr( $value['title'] ) . '" width="200" height="150">';
							$output .= '</a>';
						$output .= '</div>';
					}
				$output .= '</div>';
			}
		}

		echo $output . $after_widget;
	}

	function update( $new_instance, $old_instance ) {
		$instance = array();
		if ( ! empty( $new_instance['title'] ) ) {
			$instance['title'] = sanitize_text_field( $new_instance['title'] );
		}
		if ( ! empty( $new_instance['id'] ) ) {
			$instance['id'] = sanitize_text_field( $new_instance['id'] );
		}
		if ( ! empty( $new_instance['limit'] ) ) {
			$instance['limit'] = ( int ) $new_instance['limit'];
		}
		if ( ! empty( $new_instance['columns'] ) ) {
			$instance['columns'] = ( int ) $new_instance['columns'];
		}
		return $instance;
	}

	function form( $instance ) {
		$instance = wp_parse_args( ( array ) $instance, array( 'title' => '', 'id' => '', 'limit' => 4, 'columns' => 2 ) );
		$title    = strip_tags( $instance['title'] );
		$id       = isset( $instance['id'] ) ? $instance['id'] : array();
		$limit    = ( int ) $instance['limit'];
		$columns  = ( int ) $instance['columns'];

	?>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php _e( 'Title:', 'moon' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'id' ) ); ?>"><?php _e( 'Dribbble Account', 'moon' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'id' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'id' ) ); ?>" type="text" value="<?php echo esc_attr( $id ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'limit' ) ); ?>"><?php _e( 'Number of Photos:', 'moon' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'limit' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'limit' ) ); ?>" type="number" min="1" value="<?php echo esc_attr( $limit ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'columns' ) ); ?>"><?php _e( 'Columns (1-5):', 'moon' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'columns' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'columns' ) ); ?>" type="number" min="1" max="5" step="1" value="<?php echo esc_attr( $columns ); ?>" />
		</p>

	<?php
	}
}